@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2009 by Pavel Zinin (pashazz)                              *
  *   pzinin@gmail.com                                                     *
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -48,7 +48,7 @@ winetricks::winetricks(QString prefixName) : QWidget()
 
     this->prefix_name = prefixName;
     this->console_bin = CoreLib->getSetting("console", "bin").toString();
-    this->console_args = CoreLib->getSetting("console", "args", FALSE).toString();
+    this->console_args = CoreLib->getSetting("console", "args", false).toString();
 }
 
 void winetricks::install_winetricks() {
@@ -210,10 +210,10 @@ void winetricks::downloadwinetricks () {
 QStringList winetricks::get_stdout_lines(QString command){
     QProcess p(this);
     QString lang = CoreLib->getLocale();
-    #ifdef DEBUG
-        qDebug()<<lang;
-    #endif
-    QTextCodec *codec = QTextCodec::codecForName(lang.toAscii());
+#ifdef DEBUG
+    qDebug()<<lang;
+#endif
+    QTextCodec *codec = QTextCodec::codecForName(lang.toLatin1());
 
     p.start(command);
     p.waitForFinished();
@@ -265,7 +265,6 @@ bool winetricks::parse() {
             foreach (QString item, this->get_stdout_lines(pargs)){
                 if (item.isEmpty())
                     continue;
-
                 db_sysconfig.add_item(item.left(24).trimmed(), "exec.png", item.mid(24).trimmed(), subtype, D_PROVIDER_WINETRICKS);
             }
         }
