@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2011 by Alexey Malakhov                            *
+ *   Copyright (C) 2008-2016 by Alexey Malakhov                            *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,7 +18,7 @@
 
 #include "about.h"
 
-About::About(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
+About::About(QWidget * parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
     setupUi(this);
     setWindowTitle(tr("About %1").arg(APP_NAME));
