@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,7 +28,7 @@ class About : public QDialog, public Ui::About
 {
 	Q_OBJECT
 	public:
-		About(QWidget * parent = 0, Qt::WFlags f = 0);
+		About(QWidget * parent = 0, Qt::WindowFlags f = 0);
 
 	private slots:
 		void cmdOk_Click();
