@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,7 +18,7 @@
 
 #include "appsettings.h"
 
-AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
+AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
@@ -60,15 +60,11 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
     connect(cmdHelp, SIGNAL(clicked()), this, SLOT(cmdHelp_Click()));
+    connect(cmdVersionManager, SIGNAL(clicked()), this, SLOT(cmdVersionManager_Click()));
 
     connect(comboProxyType, SIGNAL(currentIndexChanged(QString)), this, SLOT(comboProxyType_indexChanged(QString)));
 
     //Installing event filters for get buttuns
-    cmdGetWineBin->installEventFilter(this);
-    cmdGetWineServerBin->installEventFilter(this);
-    cmdGetWineLoaderBin->installEventFilter(this);
-    cmdGetWineLibs->installEventFilter(this);
-    cmdGetWineLibs64->installEventFilter(this);
     cmdGetTarBin->installEventFilter(this);
     cmdGetMountBin->installEventFilter(this);
     cmdGetUmountBin->installEventFilter(this);
@@ -82,14 +78,6 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
 
     QSettings settings(APP_SHORT_NAME, "default");
 
-    settings.beginGroup("wine");
-    txtWineBin->setText(settings.value("WineBin").toString());
-    txtWineServerBin->setText(settings.value("ServerBin").toString());
-    txtWineLoaderBin->setText(settings.value("LoaderBin").toString());
-    txtWineLibs->setText(settings.value("WineLibs32").toString());
-    txtWineLibs64->setText(settings.value("WineLibs64").toString());
-    settings.endGroup();
-
     settings.beginGroup("logging");
     connect (cbShowTray, SIGNAL(stateChanged (int)), this, SLOT(cbShowTray_stateChanged (int)));
 
@@ -435,20 +423,20 @@ bool AppSettings::eventFilter(QObject *obj, QEvent *event){
         }
     }
 
-    return FALSE;
+    return false;
 }
 
 void AppSettings::comboProxyType_indexChanged(QString text){
     if (text==tr("No Proxy")){
-        txtProxyHost->setEnabled(FALSE);
-        txtProxyPort->setEnabled(FALSE);
-        txtProxyUser->setEnabled(FALSE);
-        txtProxyPass->setEnabled(FALSE);
+        txtProxyHost->setEnabled(false);
+        txtProxyPort->setEnabled(false);
+        txtProxyUser->setEnabled(false);
+        txtProxyPass->setEnabled(false);
     } else {
-        txtProxyHost->setEnabled(TRUE);
-        txtProxyPort->setEnabled(TRUE);
-        txtProxyUser->setEnabled(TRUE);
-        txtProxyPass->setEnabled(TRUE);
+        txtProxyHost->setEnabled(true);
+        txtProxyPort->setEnabled(true);
+        txtProxyUser->setEnabled(true);
+        txtProxyPass->setEnabled(true);
     }
 
     return;
@@ -531,12 +519,6 @@ void AppSettings::getThemes(QString selTheme, QString themeDir){
 void AppSettings::loadThemeIcons(){
     lblLogo->setPixmap(CoreLib->loadPixmap("data/exec.png"));
 
-    cmdGetWineBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineServerBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineLoaderBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineLibs->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineLibs64->setIcon(CoreLib->loadIcon("data/folder.png"));
-
     cmdGetTarBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetMountBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetUmountBin->setIcon(CoreLib->loadIcon("data/folder.png"));
@@ -559,17 +541,6 @@ void AppSettings::cmdCancel_Click(){
 }
 
 void AppSettings::cmdOk_Click(){
-    if (!checkEntry(txtWineBin->text(), "wine"))
-        return;
-
-    if (!checkEntry(txtWineServerBin->text(), "wine server"))
-        return;
-
-    if (!checkEntry(txtWineLoaderBin->text(), "wine loader"))
-        return;
-
-    if (!checkEntry(txtWineLibs->text(), "wine library", FALSE))
-        return;
 
     if (!checkEntry(txtTarBin->text(), "tar"))
         return;
@@ -619,14 +590,6 @@ void AppSettings::cmdOk_Click(){
 
     QSettings settings(APP_SHORT_NAME, "default");
 
-    settings.beginGroup("wine");
-    settings.setValue("WineBin", txtWineBin->text());
-    settings.setValue("ServerBin", txtWineServerBin->text());
-    settings.setValue("LoaderBin", txtWineLoaderBin->text());
-    settings.setValue("WineLibs32", txtWineLibs->text());
-    settings.setValue("WineLibs64", txtWineLibs64->text());
-    settings.endGroup();
-
     settings.beginGroup("logging");
     if (cbClearLogs->checkState()==Qt::Checked) {
         settings.setValue("autoClear", 1);
@@ -794,29 +757,29 @@ bool AppSettings::checkEntry(QString fileName, QString info, bool isFile){
 
     if (fileName.isEmpty()){
         switch (isFile){
-  case FALSE:
+  case false:
             QMessageBox::warning(this, tr("Error"), tr("Sorry, specify %1 directory.").arg(info));
             break;
-  case TRUE:
+  case true:
             QMessageBox::warning(this, tr("Error"), tr("Sorry, specify %1 binary.").arg(info));
             break;
         }
-        return FALSE;
+        return false;
     } else {
         if (!QFile::exists(fileName)){
             switch (isFile){
-   case FALSE:
+   case false:
                 QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 directory does not exist.").arg(info));
                 break;
-   case TRUE:
+   case true:
                 QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 binary does not exist.").arg(info));
                 break;
             }
-            return FALSE;
+            return false;
         }
     }
 
-    return TRUE;
+    return true;
 }
 
 void AppSettings::cmdHelp_Click(){
@@ -909,3 +872,9 @@ void AppSettings::cmdDesktopMenu_Remove_Click(){
     system_menu sys_menu;
     sys_menu.wipeSystemMenu();
 }
+
+void AppSettings::cmdVersionManager_Click(){
+    VersionManager* vers = new VersionManager();
+    vers->exec();
+    delete(vers);
+}
