@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,7 +23,7 @@
 #include <src/q4wine-gui/ui_AppSettings.h>
 
 #include "config.h"
-
+#include "versions.h"
 #include "q4wine-lib.h"
 
 #ifndef _OS_DARWIN_
@@ -36,11 +36,12 @@ class AppSettings : public QDialog, public Ui::AppSettings
 {
     Q_OBJECT
     public:
-        AppSettings(QWidget * parent = 0, Qt::WFlags f = 0);
+        AppSettings(QWidget * parent = 0, Qt::WindowFlags f = 0);
 
     private slots:
         void cmdCancel_Click();
         void cmdOk_Click();
+        void cmdVersionManager_Click();
         void comboProxyType_indexChanged(QString text);
         //! \brief cmdHelo click slot.
         void cmdHelp_Click();
@@ -54,7 +55,7 @@ class AppSettings : public QDialog, public Ui::AppSettings
         bool eventFilter (QObject *object, QEvent *event);
         void getThemes(QString selTheme, QString themeDir);
         void getLangs();
-        bool checkEntry(QString fileName, QString info, bool isFile = TRUE);
+        bool checkEntry(QString fileName, QString info, bool isFile = true);
         void loadThemeIcons();
 
         std::auto_ptr<QSplitter> splitter;
