@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,7 +18,7 @@
 
 #include "fakedrivesettings.h"
 
-FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
+FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
@@ -1362,7 +1362,7 @@ bool FakeDriveSettings::eventFilter(QObject *obj, QEvent *event){
     */
 
     if (obj->objectName()== "FakeDriveSettings")
-        return FALSE;
+        return false;
 
     if (event->type() == QEvent::MouseButtonRelease) {
         QString file;
@@ -1407,5 +1407,5 @@ bool FakeDriveSettings::eventFilter(QObject *obj, QEvent *event){
             }
         }
     }
-    return FALSE;
+    return false;
 }
