@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,8 +20,6 @@
 #define FAKEDRIVESETTINGS_H
 
 #include <src/q4wine-gui/ui_FakeDriveSettings.h>
-//#include <src/q4wine-gui/ui_AppSettings.h>
-#include "src/q4wine-gui/ui_InfoDialog.h"
 
 #include "config.h"
 #include "registry.h"
@@ -49,7 +47,7 @@ class FakeDriveSettings : public QDialog, public Ui::FakeDriveSettings
 {
     Q_OBJECT
 public:
-    explicit FakeDriveSettings(QString prefixName, QWidget * parent = 0, Qt::WFlags f = 0);
+    explicit FakeDriveSettings(QString prefixName, QWidget * parent = 0, Qt::WindowFlags f = 0);
     void loadPrefixSettings();
     void loadDefaultPrefixSettings();
 
