@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,7 +17,7 @@
  ***************************************************************************/
 #include "imagemanager.h"
 
-ImageManager::ImageManager(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
+ImageManager::ImageManager(QWidget * parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
 	//setModal(true);
 	setupUi(this);
@@ -66,9 +66,9 @@ void ImageManager::tableImage_showContextMenu(const QPoint){
 	menu.addAction(actionRefresh.get());
 	menu.addSeparator();
 	if (tableImage->currentRow()>=0){
-		actionRemove->setEnabled(TRUE);
+		actionRemove->setEnabled(true);
 	} else {
-		actionRemove->setEnabled(FALSE);
+		actionRemove->setEnabled(false);
 	}
 	menu.addAction(actionRemove.get());
 	menu.exec(QCursor::pos());
@@ -129,7 +129,7 @@ void ImageManager::getCDImages(void){
 
 	tableImage->resizeRowsToContents();
 	tableImage->resizeColumnsToContents();
-	tableImage->horizontalHeader()->setStretchLastSection(TRUE);
+	tableImage->horizontalHeader()->setStretchLastSection(true);
 
 	return;
 }
