@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -46,7 +46,7 @@ class ImageManager : public QDialog, public Ui::ImageManager
 	Q_OBJECT
 	public:
 		//! Class constructor
-		ImageManager(QWidget * parent = 0, Qt::WFlags f = 0);
+		ImageManager(QWidget * parent = 0, Qt::WindowFlags f = 0);
 
 	private slots:
 		//! Ok button click slot
