@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,7 +18,7 @@
 
 #include "mainwindow.h"
 
-MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt::WFlags f) : QMainWindow(parent, f){
+MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt::WindowFlags f) : QMainWindow(parent, f){
      // Loading libq4wine-core.so
 #ifdef RELEASE
     libq4wine.setFileName(_CORELIB_PATH_);
@@ -56,7 +56,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     if (startState == 1)
         this->showMinimized();
 
-    setWindowTitle(tr("%1 :. Qt4 GUI for Wine v%2").arg(APP_NAME) .arg(APP_VERS));
+    setWindowTitle(tr("%1 :. Qt GUI for Wine v%2").arg(APP_NAME) .arg(APP_VERS));
 
     std::auto_ptr<QVBoxLayout> vlayout (new QVBoxLayout);
 
@@ -200,6 +200,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     // Creating AppDBScrollWidget and place it into frameAppDBWidget layout
     appdbWidget.reset(new AppDBWidget(this));
     connect (this, SIGNAL(appdbWidget_startSearch(short int, QString)), appdbWidget.get(), SLOT(itemTrigged(short int, QString)));
+
     connect (this, SIGNAL(setAppDBFocus()), appdbWidget.get(), SLOT(setFocus()));
     tabAppDBLayout->addWidget(appdbWidget.release());
 #endif
@@ -239,9 +240,9 @@ void MainWindow::clearTmp(){
 void MainWindow::trayIcon_Activate(QSystemTrayIcon::ActivationReason reason){
     if (reason==QSystemTrayIcon::Trigger){
         if (!isVisible()){
-            setMeVisible(TRUE);
+            setMeVisible(true);
         } else {
-            setMeVisible(FALSE);
+            setMeVisible(false);
         }
     }
     return;
@@ -544,10 +545,6 @@ void MainWindow::tbwGeneral_CurrentTabChange(int tabIndex){
     }
 #ifdef WITH_WINEAPPDB
     else if (tabIndex==4){
-        if (CoreLib->getSetting("DialogFlags", "appdbBrowser", false, 0).toInt()==0){
-            InfoDialog info(1);
-            info.exec();
-        }
         emit(stopProcTimer());
         emit(setAppDBFocus());
     }
@@ -594,7 +591,7 @@ void MainWindow::mainPrograms_Click(){
      */
 
     if (!isVisible())
-        setMeVisible(TRUE);
+        setMeVisible(true);
 
     if (isMinimized ())
         showNormal ();
@@ -610,7 +607,7 @@ void MainWindow::mainProcess_Click(){
      */
 
     if (!isVisible())
-        setMeVisible(TRUE);
+        setMeVisible(true);
 
     if (isMinimized ())
         showNormal ();
@@ -625,7 +622,7 @@ void MainWindow::mainSetup_Click(){
      */
 
     if (!isVisible())
-        setMeVisible(TRUE);
+        setMeVisible(true);
 
     if (isMinimized ())
         showNormal ();
@@ -640,7 +637,7 @@ void MainWindow::mainLogging_Click(){
      */
 
     if (!isVisible())
-        setMeVisible(TRUE);
+        setMeVisible(true);
 
     if (isMinimized ())
         showNormal ();
@@ -659,7 +656,7 @@ void MainWindow::mainPrefix_Click(){
      */
 
     if (!isVisible())
-        setMeVisible(TRUE);
+        setMeVisible(true);
 
     if (isMinimized ())
         showNormal ();
@@ -773,7 +770,7 @@ void MainWindow::mainBugs_Click(){
 
 void MainWindow::mainAppDB_Click(){
     if (!isVisible())
-        setMeVisible(TRUE);
+        setMeVisible(true);
 
     if (isMinimized ())
         showNormal ();
@@ -986,7 +983,7 @@ void MainWindow::showNotifycation(const QString header, const QString message){
 void MainWindow::messageReceived(const QString message){
     if (message.isEmpty()){
         if (!isVisible())
-            this->setMeVisible(TRUE);
+            this->setMeVisible(true);
 
         if (isMinimized())
             this->showNormal ();
@@ -1035,7 +1032,7 @@ void MainWindow::getWineMenuIcons(void){
                      for (int j=0; j<parts.count(); j++){
                          if (parts.at(j).left(1)=="x"){
                              QString test = QString("0%1").arg(parts.at(j).left(4));
-                             QByteArray temp = QByteArray::fromHex(test.toAscii().data());
+                             QByteArray temp = QByteArray::fromHex(test.toLatin1().data());
                              dir.append(codec->toUnicode(temp));
                          }
 
