@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -73,7 +73,6 @@
 #include "about.h"
 #include "appsettings.h"
 #include "run.h"
-#include "infodialog.h"
 #include "fakedrivesettings.h"
 #include "src/q4wine-gui/versions.h"
 
@@ -93,7 +92,7 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 {
     Q_OBJECT
     public:
-        MainWindow(int startState, QString run_binary, QWidget * parent = 0, Qt::WFlags f = 0);
+        MainWindow(int startState, QString run_binary, QWidget * parent = 0, Qt::WindowFlags f = 0);
 
     public slots:
             void messageReceived(const QString message);
