@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -53,8 +53,8 @@ class PrefixSettings : public QDialog, public Ui::PrefixSettings
          *
          * \param  prefix_name  Current prefix name.
          */
-        PrefixSettings(QString prefix_name, QWidget * parent = 0, Qt::WFlags f = 0);
-        PrefixSettings(QWidget * parent = 0, Qt::WFlags f = 0);
+        PrefixSettings(QString prefix_name, QWidget * parent = 0, Qt::WindowFlags f = 0);
+        PrefixSettings(QWidget * parent = 0, Qt::WindowFlags f = 0);
         QString getPrefixName();
 
     private:
