@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,7 +18,7 @@
 
 #include "process.h"
 
-Process::Process (QStringList args, QString exec, QString dir, QString info, QString caption, bool showErr, QStringList env, QWidget * parent, Qt::WFlags f)
+Process::Process (QStringList args, QString exec, QString dir, QString info, QString caption, bool showErr, QStringList env, QWidget * parent, Qt::WindowFlags f)
 {
 	setupUi(this);
 
@@ -57,7 +57,7 @@ void Process::slotError(QProcess::ProcessError err){
 		QTextStream stdErr(stderr);
 		QString lang = this->getLocale();
 
-		QTextCodec *codec = QTextCodec::codecForName(lang.toAscii());
+		QTextCodec *codec = QTextCodec::codecForName(lang.toLatin1());
 		if (!codec){
 			stdErr<<"[ee] Cannot setup codec for \""<<lang<<"\""<<endl;
 			stdErr<<"[ee] Aborting current operation!"<<endl;
@@ -130,7 +130,7 @@ void Process::slotFinished(int, QProcess::ExitStatus exitc){
 		QString lang = this->getLocale();
 
 		// Read STDERR with locale support
-		QTextCodec *codec = QTextCodec::codecForName(lang.toAscii());
+		QTextCodec *codec = QTextCodec::codecForName(lang.toLatin1());
 		if (!codec){
 			stdErr<<"[ee] Cannot setup codec for \""<<lang<<"\""<<endl;
 			stdErr<<"[ee] Aborting current operation!"<<endl;
