@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -40,7 +40,7 @@ class Process : public QDialog, public Ui::Process
 {
 	Q_OBJECT
 	public:
-		Process(QStringList args, QString exec, QString dir, QString info, QString caption, bool showErr = TRUE, QStringList env = QProcess::systemEnvironment(), QWidget * parent = 0, Qt::WFlags f = 0);
+		Process(QStringList args, QString exec, QString dir, QString info, QString caption, bool showErr = true, QStringList env = QProcess::systemEnvironment(), QWidget * parent = 0, Qt::WindowFlags f = 0);
 
 	private slots:
 		void slotFinished(int, QProcess::ExitStatus);
