@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -47,7 +47,7 @@ class Progress : public QDialog, public Ui::Process
 {
 Q_OBJECT
 public:
-    explicit Progress(int action, QString path = "", QWidget * parent = 0, Qt::WFlags f = 0);
+    explicit Progress(int action, QString path = "", QWidget * parent = 0, Qt::WindowFlags f = 0);
 
 signals:
 
