@@ -18,7 +18,7 @@
 
 #include "src/q4wine-gui/versions.h"
 
-VersionManager::VersionManager(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
+VersionManager::VersionManager(QWidget * parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
@@ -186,8 +186,9 @@ void VersionManager::cmdOk_Click()
     if (!fileExists(this->txtWineLibs32->text(), true))
         return;
 
-    if (!fileExists(this->txtWineLibs64->text(), true))
-        return;
+    if (!this->txtWineLibs64->text().isEmpty())
+        if (!fileExists(this->txtWineLibs64->text(), true))
+            return;
 
     accept();
     return;
