@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -39,7 +39,9 @@
 #endif
 
 //Qt includes
+#include <QDrag>
 #include <QMenu>
+#include <QMimeData>
 #include <QDesktopServices>
 #include <QListView>
 #include <QClipboard>
@@ -133,7 +135,7 @@ private slots:
       void iconCopyQ4WineCmd_Click(void);
 
 
-      void menuRun_triggered(QAction*);
+      void menuRunRecent_triggered(QAction* action);
       void menuMount_triggered(QAction*);
       void menuUmount_Click(void);
 
