@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -193,17 +193,23 @@ void LoggingWidget::treeWidget_itemClicked (QTreeWidgetItem * item, int colum){
                         }
 
                         if (rows.at(j) == "Exec string:"){
-                             iconItem->setText(tr("Exec string:"));
-                             iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
-                         } else if (rows.at(j) == "Exit code:"){
-                             iconItem->setText(tr("Exit code:"));
-                             iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
-                         } else if (rows.at(j) == "App STDOUT and STDERR output:"){
-                             iconItem->setText(tr("App STDOUT and STDERR output:"));
-                             iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
-                         } else {
-                              iconItem->setText(rows.at(j));
-                         }
+                            iconItem->setText(tr("Exec string:"));
+                            iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
+                        } else if (rows.at(j) == "Prerun Exec string:"){
+                            iconItem->setText(tr("Prerun Exec string:"));
+                            iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
+                        } else if (rows.at(j) == "Postrun Exec string:"){
+                            iconItem->setText(tr("Postrun Exec string:"));
+                            iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
+                        } else if (rows.at(j) == "Exit code:"){
+                            iconItem->setText(tr("Exit code:"));
+                            iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
+                        } else if (rows.at(j) == "App STDOUT and STDERR output:"){
+                            iconItem->setText(tr("App STDOUT and STDERR output:"));
+                            iconItem->setIcon(CoreLib->loadIcon("data/down_log.png"));
+                        } else {
+                            iconItem->setText(rows.at(j));
+                        }
 
                         iconItem.release();
                     }
@@ -323,7 +329,7 @@ void LoggingWidget::logExport_Click(){
                 return;
             }
 
-            file.write(list.toAscii().data(), qstrlen(list.toAscii().data()));
+            file.write(list.toLatin1().data(), qstrlen(list.toLatin1().data()));
 
             file.close();
         }
@@ -392,7 +398,7 @@ void LoggingWidget::getLogRecords(void){
             std::auto_ptr<QTreeWidgetItem> prefixItem (new QTreeWidgetItem(treeWidget.get()));
             prefixItem->setText(0, QString("%1").arg(p_list.at(i)));
             prefixItem->setIcon(0, CoreLib->loadIcon("data/wine.png"));
-            prefixItem->setExpanded (TRUE);
+            prefixItem->setExpanded (true);
             treeWidget->addTopLevelItem(prefixItem.get());
 
             for (int j=0; j<app_list.count(); j++){
