@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -222,7 +222,7 @@ void PrefixConfigWidget::createTree(){
         if (item->text(0)==this->provider){
 
             this->treeWidget.get()->setCurrentItem(item.get());
-            this->treeWidget.get()->topLevelItem(i)->setExpanded(TRUE);
+            this->treeWidget.get()->topLevelItem(i)->setExpanded(true);
             this->treeWidget_itemClicked(item.get(), 0);
             item.release();
             break;
