@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -106,27 +106,27 @@ void PrefixControlWidget::createActions(){
     prefixImport.reset(new QAction(CoreLib->loadIcon("data/down.png"), tr("Import prefix"), this));
     prefixImport->setStatusTip(tr("Import prefix"));
     connect(prefixImport.get(), SIGNAL(triggered()), this, SLOT(prefixImport_Click()));
-    prefixImport->setEnabled(FALSE);
+    prefixImport->setEnabled(false);
 
     prefixExport.reset(new QAction(CoreLib->loadIcon("data/up.png"), tr("Export prefix"), this));
     prefixExport->setStatusTip(tr("Export prefix"));
     connect(prefixExport.get(), SIGNAL(triggered()), this, SLOT(prefixExport_Click()));
-    prefixExport->setEnabled(FALSE);
+    prefixExport->setEnabled(false);
 
     prefixDelete.reset(new QAction(CoreLib->loadIcon("data/kill.png"), tr("Delete prefix"), this));
     prefixDelete->setStatusTip(tr("Delete prefix"));
     connect(prefixDelete.get(), SIGNAL(triggered()), this, SLOT(prefixDelete_Click()));
-    prefixDelete->setEnabled(FALSE);
+    prefixDelete->setEnabled(false);
 
     prefixSettings.reset(new QAction(CoreLib->loadIcon("data/configure.png"), tr("Edit prefix settings"), this));
     prefixSettings->setStatusTip(tr("Edit prefix settings"));
     connect(prefixSettings.get(), SIGNAL(triggered()), this, SLOT(prefixSettings_Click()));
-    prefixSettings->setEnabled(FALSE);
+    prefixSettings->setEnabled(false);
 
     prefixSetup.reset(new QAction(CoreLib->loadIcon("data/eject.png"), tr("Set up prefix fake drive"), this));
     prefixSetup->setStatusTip(tr("Set up prefix fake drive and applications"));
     connect(prefixSetup.get(), SIGNAL(triggered()), this, SLOT(prefixSetup_Click()));
-    prefixSetup->setEnabled(FALSE);
+    prefixSetup->setEnabled(false);
 
     menu.reset(new QMenu(this));
     menu->addAction(prefixAdd.get());
@@ -215,6 +215,7 @@ void PrefixControlWidget::prefixDelete_Click(){
         return;
 
     QString prefixName = model->index(prefixTable->currentIndex().row(), 0, QModelIndex()).data().toString();
+    QString prefixPath = model->index(prefixTable->currentIndex().row(), 3, QModelIndex()).data().toString();
 
     if (prefixName.isEmpty())
         return;
@@ -224,7 +225,22 @@ void PrefixControlWidget::prefixDelete_Click(){
             return;
     }
 
-    if(QMessageBox::warning(this, tr("Warning"), tr("Do you really wish to delete the prefix named \"%1\" and all associated icons?").arg(prefixName), QMessageBox::Ok, QMessageBox::Cancel)==QMessageBox::Ok){
+    QMessageBox msgBox(this);
+    QCheckBox dontPrompt(QObject::tr("Remove prefix directory"), &msgBox);
+    dontPrompt.blockSignals(true);
+
+    msgBox.setIcon(QMessageBox::Warning);
+    msgBox.setWindowTitle(tr("Warning"));
+    msgBox.setText(tr("Do you really wish to delete the prefix named \"%1\" and all associated icons?").arg(prefixName));
+    msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
+    msgBox.setDefaultButton(QMessageBox::Cancel);
+
+    msgBox.addButton(&dontPrompt, QMessageBox::ActionRole);
+
+    if(msgBox.exec()==QMessageBox::Ok){
+        if (dontPrompt.checkState() == Qt::Checked){
+            CoreLib->removeDirectory(prefixPath);
+        }
         if (db_icon.delIconsByPrefixName(prefixName))
             if(db_dir.delDir(prefixName)){
                 db_prefix.delByName(prefixName);
@@ -356,7 +372,7 @@ void PrefixControlWidget::prefixExport_Click(){
     qDebug()<<"[ii] row is valid";
 #endif
     QString prefixName = model->index(prefixTable->currentIndex().row(), 0, QModelIndex()).data().toString();
-    QString prefixPath = model->index(prefixTable->currentIndex().row(), 2, QModelIndex()).data().toString();
+    QString prefixPath = model->index(prefixTable->currentIndex().row(), 3, QModelIndex()).data().toString();
 
 #ifdef DEBUG
     qDebug()<<"[ii] name: " << prefixName << " Path: " << prefixPath;
