@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -222,9 +222,9 @@ void PrefixTreeWidget::getPrefixes(){
             prefixItem->setText(0, QString("%1").arg(list.at(i)));
             prefixItem->setIcon(0, CoreLib->loadIcon("data/wine.png"));
             if (CoreLib->getSetting("TreeWidget", "State", false, D_TREE_EXPAND).toInt()==D_TREE_EXPAND){
-                prefixItem->setExpanded (TRUE);
+                prefixItem->setExpanded (true);
             } else {
-                prefixItem->setExpanded (FALSE);
+                prefixItem->setExpanded (false);
             }
             this->addTopLevelItem(prefixItem.get());
 
