@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -220,8 +220,8 @@ void WineProcessWidget::procKillSelected_Click(void){
     for (int i=0; i<procList.count(); i++){
         QString cmd = QString("kill -9 %1").arg(procList.at(i));
 
-        if (system(cmd.toAscii().data())==-1){
-            QMessageBox::warning(this, tr("Error"), tr("Cannot run: %1").arg(cmd.toAscii().data()), QMessageBox::Ok);
+        if (system(cmd.toLatin1().data())==-1){
+            QMessageBox::warning(this, tr("Error"), tr("Cannot run: %1").arg(cmd.toLatin1().data()), QMessageBox::Ok);
 #ifdef DEBUG
             qDebug()<<"[EE] Fail to run: "<<cmd;
 #endif
@@ -266,7 +266,7 @@ void WineProcessWidget::procKillWine_Click(void){
 
 void WineProcessWidget::procRenice_Click(void){
     bool ok=false;
-    int newNice = QInputDialog::getInteger(this, tr("Select process priority"), tr("<p>Priority value can be in<br>the range from PRIO_MIN (-20)<br>to PRIO_MAX (20).</p><p>See \"man renice\" for details.</p>"), 0, -20, 20, 1, &ok);
+    int newNice = QInputDialog::getInt(this, tr("Select process priority"), tr("<p>Priority value can be in<br>the range from PRIO_MIN (-20)<br>to PRIO_MAX (20).</p><p>See \"man renice\" for details.</p>"), 0, -20, 20, 1, &ok);
     if (!ok)
         return;
 
