@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -45,8 +45,8 @@ public:
 	 * \param  WizardType	Type of wizard scenario.
 	 * \param  var1			This variable used for different scenarion actions.
 	 */
-	WineDriveDialog(QStringList removeLetters, QWidget * parent = 0, Qt::WFlags f = 0);
-	WineDriveDialog(QStringList removeLetters, QString driveLetter, QString drivePath, QString driveType, QWidget * parent = 0, Qt::WFlags f = 0);
+	WineDriveDialog(QStringList removeLetters, QWidget * parent = 0, Qt::WindowFlags f = 0);
+	WineDriveDialog(QStringList removeLetters, QString driveLetter, QString drivePath, QString driveType, QWidget * parent = 0, Qt::WindowFlags f = 0);
 
 	QString getLetter();
 	QString getPath();
