@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -60,7 +60,7 @@ class Wizard : public QDialog, public Ui::Wizard
          * \param  WizardType	Type of wizard scenario.
          * \param  var1			This variable used for different scenarion actions.
          */
-        Wizard(int WizardType, QString var1 = "", QWidget * parent = 0, Qt::WFlags f = 0);
+        Wizard(int WizardType, QString var1 = "", QWidget * parent = 0, Qt::WindowFlags f = 0);
         QString getPrefixName();
 
     private slots:
@@ -79,9 +79,12 @@ class Wizard : public QDialog, public Ui::Wizard
         //! \brief cmdHelo click slot.
         void cmdHelp_Click();
 
-        //! \brief mounts profile combobox index cahnge slot
+        //! \brief mounts profile combobox index cahnge slot.
         void comboMountProfiles_currentIndexChanged(int index);
 
+        //! \brief open start page of requested.
+        void cmdFirstSteps_click();
+
     private:
         //! \brief Function for updateing scene elements.
         void updateScena();
@@ -89,7 +92,7 @@ class Wizard : public QDialog, public Ui::Wizard
         int Scena, Page, TotalPage;
 
         //! \brief Function for checking user selected elements.
-        bool checkEntry(QString fileName, QString info, bool isFile = TRUE);
+        bool checkEntry(QString fileName, QString info, bool isFile = true);
 
         //! Database prefix class defenition.
         Prefix db_prefix;
