@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -186,16 +186,18 @@ QString WineObject::createEnvString(){
 int WineObject::runSys(){
 
     if (!this->useConsole){
-        int ret = this->runScript(this->prerun_script);
-        if ( ret != 0){
-            return 255;
+        if (!this->prerun_script.isEmpty()){
+            int ret = this->runScript(this->prerun_script);
+            if ( ret != 0){
+                return 255;
+            }
         }
     }
 
     QString env = this->createEnvString();
     QString app_stdout;
 
-    QTextCodec *codec = QTextCodec::codecForName(CoreLib->getLocale().toAscii());
+    QTextCodec *codec = QTextCodec::codecForName(CoreLib->getLocale().toLatin1());
 
     FILE *fp;
     int status;
@@ -327,9 +329,11 @@ int WineObject::runSys(){
     status = pclose(fp);
 
     if (!this->useConsole){
-        int ret = this->runScript(this->postrun_script);
-        if (ret != 0)
-            return ret;
+        if (!this->postrun_script.isEmpty()){
+            int ret = this->runScript(this->postrun_script, false);
+            if (ret != 0)
+                return ret;
+        }
     }
 
     stdout.append("Exit code:");
@@ -356,14 +360,14 @@ int WineObject::run(){
     return status;
 }
 
-int WineObject::runScript(QString script_path){
+int WineObject::runScript(QString script_path, bool pre_run){
     int status;
     FILE *fp;
     char path[PATH_MAX];
     QString stdout, app_stdout;
 
     QString env = this->createEnvString();
-    QTextCodec *codec = QTextCodec::codecForName(CoreLib->getLocale().toAscii());
+    QTextCodec *codec = QTextCodec::codecForName(CoreLib->getLocale().toLatin1());
 
     QString run_string = "";
     if (!env.isEmpty()){
@@ -371,9 +375,9 @@ int WineObject::runScript(QString script_path){
         run_string.append(env);
     }
 
-    run_string.append(" /bin/sh -c \"");
+    run_string.append(" /bin/sh -c ");
     run_string.append(script_path);
-    run_string.append("\" 2>&1");
+    run_string.append(" 2>&1");
 
     fp = popen(codec->fromUnicode(run_string).data(), "r");
     if (fp == NULL)
@@ -386,6 +390,14 @@ int WineObject::runScript(QString script_path){
     status = pclose(fp);
     if (status != 0){
         if (this->logEnabled){
+            if (pre_run){
+                stdout.append("Prerun Exec string:");
+            } else {
+                stdout.append("Postrun Exec string:");
+            }
+            stdout.append("\n");
+            stdout.append(run_string);
+            stdout.append("\n");
             stdout.append("Exit code:");
             stdout.append("\n");
             stdout.append(QString("%1").arg(status));
