@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -72,7 +72,7 @@ public:
 
 private:
     int runSys();
-    int runScript(QString script_path);
+    int runScript(QString script_path, bool pre_run=true);
     void logStdout(int status);
 
     //! This is need for libq4wine-core.so import;
