@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -580,6 +580,11 @@ void corelib::getBuildFlags(){
     QTextStream Qcout(stdout);
     Qcout<<QObject::tr("Buildtime flags are:")<<endl<<endl;
     Qcout<<qSetFieldWidth(25)<<left<<" CMAKE_INSTALL_PREFIX"<<QString::fromUtf8(APP_PREF)<<qSetFieldWidth(0)<<endl<<endl;
+#ifdef QT5
+    Qcout<<qSetFieldWidth(25)<<left<<" QT5"<<"ON"<<qSetFieldWidth(0)<<endl;
+#else
+    Qcout<<qSetFieldWidth(25)<<left<<" QT5"<<"OFF"<<qSetFieldWidth(0)<<endl;
+#endif
 #ifdef RELEASE
     Qcout<<qSetFieldWidth(25)<<left<<" RELEASE"<<"ON"<<qSetFieldWidth(0)<<endl;
 #else
@@ -713,11 +718,14 @@ QStringList corelib::getWineLibsPath(void) {
     if (!string.isEmpty()){
         QStringList libs_list = string.split("\n");
 #ifdef _OS_LINUX_
-        QRegExp rx_info(".*\\((.*)\\) => (.*\\.so$)");
+        QRegExp rx_info(".*\\((.*)\\) => (.*\\.so.*$)");
 #else
         QRegExp rx_info("(.*) => (.*\\.so.*)");
 #endif
         foreach (QString lib_info, libs_list){
+#ifdef DEBUG
+            qDebug()<<"[ii] work with: " <<  lib_info;
+#endif
             int pos = rx_info.indexIn(lib_info);
             QString arch, path;
             if (pos > -1) {
@@ -726,11 +734,15 @@ QStringList corelib::getWineLibsPath(void) {
             } else {
                 continue;
             }
+#ifdef DEBUG
+            qDebug()<<"[ii] Found: " <<  arch << " " << path;
+#endif
             if (path.isEmpty()){
                 qDebug()<<"[EE] No winelib.so found in: " << lib_info;
                 continue;
             }
             QFileInfo file(path);
+
             if (!file.exists()){
                 qDebug()<<"[EE] File does not exist: " << path;
                 continue;
@@ -1555,7 +1567,7 @@ QStringList corelib::getCdromDevices(void) const{
                 QString lang=this->getLocale();
 
                 // Read STDERR with locale support
-                QTextCodec *codec = QTextCodec::codecForName(lang.toAscii());
+                QTextCodec *codec = QTextCodec::codecForName(lang.toLatin1());
                 QString string = codec->toUnicode(myProcess.readAllStandardError());
 
                 if (!string.isEmpty()){
@@ -1906,7 +1918,7 @@ QStringList corelib::getCdromDevices(void) const{
                 for (int j=0; j<parts.count(); j++){
                     if (parts.at(j).left(1)=="x"){
                         QString test = QString("0%1").arg(parts.at(j).left(4));
-                        QByteArray temp = QByteArray::fromHex(test.toAscii().data());
+                        QByteArray temp = QByteArray::fromHex(test.toLatin1().data());
                         ret.append(codec->toUnicode(temp));
                     }
 
@@ -2033,8 +2045,6 @@ QStringList corelib::getCdromDevices(void) const{
 #ifdef DEBUG
                     qDebug()<<"[DD] Remove dir "<<list.at(i).absoluteFilePath();
 #endif
-                    if (not dir.rmdir(list.at(i).absoluteFilePath()))
-                        return false;
                 } else {
 #ifdef DEBUG
                     qDebug()<<"[DD] Remove file "<< list.at(i).absoluteFilePath();
@@ -2043,5 +2053,7 @@ QStringList corelib::getCdromDevices(void) const{
                         return false;
                 }
             }
+            if (not dir.rmdir(dirPath))
+                return false;
             return true;
         }
