@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>
+# Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,10 @@ D_TXTDIR = os.path.join(os.path.dirname(__file__), '../')
 class AuthrosTxtTemplate:
     def __init__(self):
         filename = os.path.join(D_TXTDIR, 'AUTHORS')
-	print("-- Writing %s --\n" % filename)
-	self.header__ = open(filename, 'w')
-	self.header()
-	self.index__=2
+        print("-- Writing %s --\n" % filename)
+        self.header__ = open(filename, 'w')
+        self.header()
+        self.index__=2
 
     def close(self):
         self.header__.close()
@@ -69,14 +69,14 @@ class AuthrosHtmlTemplate:
         filename = os.path.join(D_DATADIR, 'authors.h')
         print("-- Writing %s --\n" % filename)
         self.header__ = open(filename, 'w')
-	self.header()
+        self.header()
 
     def close(self):
         self.header__.close()
 
     def header(self):
         self.header__.write("""/***************************************************************************
-*   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+*   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -143,7 +143,7 @@ def generate_authors():
     print("-- Reading %s --\n" % filename)
 
     with open(filename, 'r') as f:
-       data = yaml.safe_load(f)
+        data = yaml.safe_load(f)
 
     html_tpl = AuthrosHtmlTemplate()
     txt_tpl = AuthrosTxtTemplate()
@@ -151,7 +151,7 @@ def generate_authors():
     for group, persons in data.iteritems():
         print("-- Parse group T_%s --\n" % group.upper())
         html_tpl.head(group)
-	txt_tpl.head(group)
+        txt_tpl.head(group)
         for person in persons:
             nick = ""
             if person.has_key('nick'):
@@ -183,7 +183,7 @@ def generate_authors():
 
 
 if __name__ == '__main__':
-    parser = argparse.ArgumentParser(description='Parse authors.jaml file and create authors.h file.')
+    parser = argparse.ArgumentParser(description='Parse authors.yaml file and create authors.h file.')
     parser.add_argument('--generate', dest='generate', action='store_true',
                         required=True,
                         help='Generate authors.h file')
